🔖 [Table of Contents](../README.md) / [Oops, I Did It Again](README.md)

# Using The Same Variable to Define Different Task

```python
from zrb import runner, CmdTask


```

🔖 [Table of Contents](../README.md) / [Oops, I Did It Again](README.md)
